==> bfom-blog-0.1.4.crate: bfom-blog-0.1.4/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.4 (2022-03-31)

### New Features

 - <csr-id-a757e7676751aed0a8190b470390266390d98fde/> can now copy over any filetyoe required while also excluding certain directories

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - can now copy over any filetyoe required while also excluding certain directories (a757e76)
</details>

## v0.1.3 (2022-01-27)

### Bug Fixes

 - <csr-id-492b7baae4c381636904a85bd1bf74589222187e/> fixing some formatting

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.38, bfom v0.1.37, bfom-blog v0.1.3 (d9f4f61)
    - fixing some formatting (492b7ba)
</details>

## v0.1.2 (2022-01-27)

### Bug Fixes

 - <csr-id-228ceb2d9130a02dc84243e39843bc0dfbd4a9c0/> manually bumping
 - <csr-id-0e2d48ea81250590149ce57c55d1119bb62364c5/> for bumping
 - <csr-id-dbc2ffbbc6763926fd68ec94a0e8017f39e337bc/> for bumping the package
 - <csr-id-7972d63dec99cf5b3ea5b7f268b91e680483d998/> for bumping the package
 - <csr-id-73c430c5aab75e36d7c9d84343e0e9b45c5ee6f7/> for bumping the package for testing

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release.
 - 5 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (eaf2e2a)
    - for bumping the package for testing (73c430c)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (b92d078)
    - for bumping the package (7972d63)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (dade144)
    - for bumping the package (dbc2ffb)
    - Bump bfom-blog v0.1.2 (6e5f4f8)
    - manually bumping (228ceb2)
    - for bumping (0e2d48e)
</details>

## v0.1.1 (2022-01-27)

### Bug Fixes

 - <csr-id-6605d48ae4b1cba33b691bb225781c6bc66213b9/> the back and forward buttons stay on teh current pager by using #

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release over the course of 5 calendar days.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-blog v0.1.1 (097e1a8)
    - the back and forward buttons stay on teh current pager by using # (6605d48)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.1 (4a70751)
    - going to ttry out teh docs from the tool (71e3a84)
</details>

## v0.1.0 (2022-01-22)

### New Features

 - <csr-id-09eec87feccb7d687261c2492dac681439168d5a/> now has pagination  on the blog
 - <csr-id-890dcd8119b6ef2db8f2c201ec915c2d1e4ff4a6/> now can handle teh replacements with respect to teh template type
 - <csr-id-e8d08732d6bc23282f545946a737b2633e047f02/> adapted to have easier subdirectories
 - <csr-id-76709b54674db955e30f809fb3653bffd1984d36/> split up the general conversion and my own blog, will allow me to customise the blog as much as I like
 - <csr-id-762b9fa6eb8d67e952af4c213da28196be338fd9/> created new sub dir in teh project, specifically for my own blog

### Bug Fixes

 - <csr-id-82c47a4ed01cde235fbe59e8097077708673bb2d/> better handling of blogs and templates
 - <csr-id-4a96393f56f8989c0d4a9a9b193177f2929ac523/> switching to 2021 seems to be fine

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release.
 - 8 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.36, bfom v0.1.35, bfom-blog v0.1.0 (efc92c2)
    - improved the formatting (cd87337)
    - now has pagination  on the blog (09eec87)
    - now can handle teh replacements with respect to teh template type (890dcd8)
    - better handling of blogs and templates (82c47a4)
    - adapted to have easier subdirectories (e8d0873)
    - switching to 2021 seems to be fine (4a96393)
    - split up the general conversion and my own blog, will allow me to customise the blog as much as I like (76709b5)
    - created new sub dir in teh project, specifically for my own blog (762b9fa)
</details>

==> bfom-blog-0.1.6.crate: bfom-blog-0.1.6/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.6 (2022-04-01)

### Bug Fixes

 - <csr-id-240141787daf00e979414b3798cb4c1bb5016fef/> now copies all files except for those forbidden

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - now copies all files except for those forbidden (2401417)
</details>

## v0.1.5 (2022-04-01)

### New Features

 - <csr-id-42eaa856e3de9b3e1096198cc7620a85c2629bc5/> modified to accept range of filetypes

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 3 commits contributed to the release.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.41, bfom-blog v0.1.5 (6d12b58)
    - fmt and clippy (1fbfe10)
    - modified to accept range of filetypes (42eaa85)
</details>

## v0.1.4 (2022-03-31)

### New Features

 - <csr-id-a757e7676751aed0a8190b470390266390d98fde/> can now copy over any filetyoe required while also excluding certain directories

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.40, bfom-blog v0.1.4 (3cab792)
    - can now copy over any filetyoe required while also excluding certain directories (a757e76)
</details>

## v0.1.3 (2022-01-27)

### Bug Fixes

 - <csr-id-492b7baae4c381636904a85bd1bf74589222187e/> fixing some formatting

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 2 commits contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.38, bfom v0.1.37, bfom-blog v0.1.3 (d9f4f61)
    - fixing some formatting (492b7ba)
</details>

## v0.1.2 (2022-01-27)

### Bug Fixes

 - <csr-id-228ceb2d9130a02dc84243e39843bc0dfbd4a9c0/> manually bumping
 - <csr-id-0e2d48ea81250590149ce57c55d1119bb62364c5/> for bumping
 - <csr-id-dbc2ffbbc6763926fd68ec94a0e8017f39e337bc/> for bumping the package
 - <csr-id-7972d63dec99cf5b3ea5b7f268b91e680483d998/> for bumping the package
 - <csr-id-73c430c5aab75e36d7c9d84343e0e9b45c5ee6f7/> for bumping the package for testing

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release.
 - 5 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (eaf2e2a)
    - for bumping the package for testing (73c430c)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (b92d078)
    - for bumping the package (7972d63)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (dade144)
    - for bumping the package (dbc2ffb)
    - Bump bfom-blog v0.1.2 (6e5f4f8)
    - manually bumping (228ceb2)
    - for bumping (0e2d48e)
</details>

## v0.1.1 (2022-01-27)

### Bug Fixes

 - <csr-id-6605d48ae4b1cba33b691bb225781c6bc66213b9/> the back and forward buttons stay on teh current pager by using #

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 4 commits contributed to the release over the course of 5 calendar days.
 - 2 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-blog v0.1.1 (097e1a8)
    - the back and forward buttons stay on teh current pager by using # (6605d48)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.1 (4a70751)
    - going to ttry out teh docs from the tool (71e3a84)
</details>

## v0.1.0 (2022-01-22)

### New Features

 - <csr-id-09eec87feccb7d687261c2492dac681439168d5a/> now has pagination  on the blog
 - <csr-id-890dcd8119b6ef2db8f2c201ec915c2d1e4ff4a6/> now can handle teh replacements with respect to teh template type
 - <csr-id-e8d08732d6bc23282f545946a737b2633e047f02/> adapted to have easier subdirectories
 - <csr-id-76709b54674db955e30f809fb3653bffd1984d36/> split up the general conversion and my own blog, will allow me to customise the blog as much as I like
 - <csr-id-762b9fa6eb8d67e952af4c213da28196be338fd9/> created new sub dir in teh project, specifically for my own blog

### Bug Fixes

 - <csr-id-82c47a4ed01cde235fbe59e8097077708673bb2d/> better handling of blogs and templates
 - <csr-id-4a96393f56f8989c0d4a9a9b193177f2929ac523/> switching to 2021 seems to be fine

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release.
 - 8 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.36, bfom v0.1.35, bfom-blog v0.1.0 (efc92c2)
    - improved the formatting (cd87337)
    - now has pagination  on the blog (09eec87)
    - now can handle teh replacements with respect to teh template type (890dcd8)
    - better handling of blogs and templates (82c47a4)
    - adapted to have easier subdirectories (e8d0873)
    - switching to 2021 seems to be fine (4a96393)
    - split up the general conversion and my own blog, will allow me to customise the blog as much as I like (76709b5)
    - created new sub dir in teh project, specifically for my own blog (762b9fa)
</details>
